@@ -7,13 +7,13 @@
 enum fio_opt_type {
 	FIO_OPT_STR = 0,
 	FIO_OPT_STR_VAL,
-	FIO_OPT_STR_VAL_INT,
 	FIO_OPT_STR_VAL_TIME,
 	FIO_OPT_STR_STORE,
 	FIO_OPT_RANGE,
 	FIO_OPT_INT,
 	FIO_OPT_BOOL,
 	FIO_OPT_STR_SET,
+	FIO_OPT_DEPRECATED,
 };
 
 /*
@@ -25,6 +25,7 @@ struct value_pair {
 	const char *help;		/* help text for sub option */
 };
 
+#define OPT_LEN_MAX 	1024
 #define PARSE_MAX_VP	16
 
 /*
@@ -41,6 +42,7 @@ struct fio_option {
 	unsigned int maxval;		/* max and min value */
 	int minval;
 	int neg;			/* negate value stored */
+	int prio;
 	void *cb;			/* callback */
 	const char *help;		/* help text for option */
 	const char *def;		/* default setting */
@@ -51,6 +53,7 @@ struct fio_option {
 typedef int (str_cb_fn)(void *, char *);
 
 extern int parse_option(const char *, struct fio_option *, void *);
+extern void sort_options(char **, struct fio_option *, int);
 extern int parse_cmd_option(const char *t, const char *l, struct fio_option *, void *);
 extern int show_cmd_help(struct fio_option *, const char *);
 extern void fill_default_options(void *, struct fio_option *);
@@ -58,6 +61,7 @@ extern void options_init(struct fio_option *);
 
 extern void strip_blank_front(char **);
 extern void strip_blank_end(char *);
+extern int str_to_decimal(const char *, long long *, int);
 
 /*
  * Handlers for the options
